@@ -63,9 +63,48 @@ class TestCoreMetadataConstructor:
             _ = builder.config.core_metadata_constructor
 
 
+class TestStrictNaming:
+    def test_default(self, isolation):
+        builder = SdistBuilder(str(isolation))
+
+        assert builder.config.strict_naming is builder.config.strict_naming is True
+
+    def test_target(self, isolation):
+        config = {'tool': {'hatch': {'build': {'targets': {'sdist': {'strict-naming': False}}}}}}
+        builder = SdistBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is False
+
+    def test_target_not_boolean(self, isolation):
+        config = {'tool': {'hatch': {'build': {'targets': {'sdist': {'strict-naming': 9000}}}}}}
+        builder = SdistBuilder(str(isolation), config=config)
+
+        with pytest.raises(TypeError, match='Field `tool.hatch.build.targets.sdist.strict-naming` must be a boolean'):
+            _ = builder.config.strict_naming
+
+    def test_global(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': False}}}}
+        builder = SdistBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is False
+
+    def test_global_not_boolean(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': 9000}}}}
+        builder = SdistBuilder(str(isolation), config=config)
+
+        with pytest.raises(TypeError, match='Field `tool.hatch.build.strict-naming` must be a boolean'):
+            _ = builder.config.strict_naming
+
+    def test_target_overrides_global(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': False, 'targets': {'sdist': {'strict-naming': True}}}}}}
+        builder = SdistBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is True
+
+
 class TestConstructSetupPyFile:
     def test_default(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0'}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0'}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file([]) == helpers.dedent(
@@ -81,7 +120,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_packages(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0'}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0'}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -101,7 +140,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_description(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'description': 'foo'}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'description': 'foo'}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -124,7 +163,7 @@ class TestConstructSetupPyFile:
     def test_readme(self, helpers, isolation):
         config = {
             'project': {
-                'name': 'my__app',
+                'name': 'My.App',
                 'version': '0.1.0',
                 'readme': {'content-type': 'text/markdown', 'text': 'test content\n'},
             }
@@ -149,7 +188,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_authors_name(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'authors': [{'name': 'foo'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'authors': [{'name': 'foo'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -170,7 +209,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_authors_email(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'authors': [{'email': 'foo@domain'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'authors': [{'email': 'foo@domain'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -192,7 +231,7 @@ class TestConstructSetupPyFile:
 
     def test_authors_name_and_email(self, helpers, isolation):
         config = {
-            'project': {'name': 'my__app', 'version': '0.1.0', 'authors': [{'email': 'bar@domain', 'name': 'foo'}]}
+            'project': {'name': 'My.App', 'version': '0.1.0', 'authors': [{'email': 'bar@domain', 'name': 'foo'}]}
         }
         builder = SdistBuilder(str(isolation), config=config)
 
@@ -214,7 +253,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_authors_multiple(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'authors': [{'name': 'foo'}, {'name': 'bar'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'authors': [{'name': 'foo'}, {'name': 'bar'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -235,7 +274,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_maintainers_name(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'maintainers': [{'name': 'foo'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'maintainers': [{'name': 'foo'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -256,7 +295,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_maintainers_email(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'maintainers': [{'email': 'foo@domain'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'maintainers': [{'email': 'foo@domain'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -278,7 +317,7 @@ class TestConstructSetupPyFile:
 
     def test_maintainers_name_and_email(self, helpers, isolation):
         config = {
-            'project': {'name': 'my__app', 'version': '0.1.0', 'maintainers': [{'email': 'bar@domain', 'name': 'foo'}]}
+            'project': {'name': 'My.App', 'version': '0.1.0', 'maintainers': [{'email': 'bar@domain', 'name': 'foo'}]}
         }
         builder = SdistBuilder(str(isolation), config=config)
 
@@ -300,7 +339,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_maintainers_multiple(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'maintainers': [{'name': 'foo'}, {'name': 'bar'}]}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'maintainers': [{'name': 'foo'}, {'name': 'bar'}]}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -321,7 +360,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_classifiers(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'classifiers': ['foo', 'bar']}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'classifiers': ['foo', 'bar']}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -345,7 +384,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_dependencies(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'dependencies': ['foo==1', 'bar==5']}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'dependencies': ['foo==1', 'bar==5']}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -369,7 +408,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_dependencies_extra(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'dependencies': ['foo==1', 'bar==5']}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'dependencies': ['foo==1', 'bar==5']}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')], ['baz==3']) == helpers.dedent(
@@ -396,7 +435,7 @@ class TestConstructSetupPyFile:
     def test_optional_dependencies(self, helpers, isolation):
         config = {
             'project': {
-                'name': 'my__app',
+                'name': 'My.App',
                 'version': '0.1.0',
                 'optional-dependencies': {
                     'feature2': ['foo==1; python_version < "3"', 'bar==5'],
@@ -433,7 +472,7 @@ class TestConstructSetupPyFile:
         )
 
     def test_scripts(self, helpers, isolation):
-        config = {'project': {'name': 'my__app', 'version': '0.1.0', 'scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}}}
+        config = {'project': {'name': 'My.App', 'version': '0.1.0', 'scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}}}
         builder = SdistBuilder(str(isolation), config=config)
 
         assert builder.construct_setup_py_file(['my_app', os.path.join('my_app', 'pkg')]) == helpers.dedent(
@@ -460,7 +499,7 @@ class TestConstructSetupPyFile:
 
     def test_gui_scripts(self, helpers, isolation):
         config = {
-            'project': {'name': 'my__app', 'version': '0.1.0', 'gui-scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}}
+            'project': {'name': 'My.App', 'version': '0.1.0', 'gui-scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}}
         }
         builder = SdistBuilder(str(isolation), config=config)
 
@@ -489,7 +528,7 @@ class TestConstructSetupPyFile:
     def test_entry_points(self, helpers, isolation):
         config = {
             'project': {
-                'name': 'my__app',
+                'name': 'My.App',
                 'version': '0.1.0',
                 'entry-points': {
                     'foo': {'bar': 'pkg:foo', 'foo': 'pkg:bar'},
@@ -528,7 +567,7 @@ class TestConstructSetupPyFile:
     def test_all(self, helpers, isolation):
         config = {
             'project': {
-                'name': 'my__app',
+                'name': 'My.App',
                 'version': '0.1.0',
                 'description': 'foo',
                 'readme': {'content-type': 'text/markdown', 'text': 'test content\n'},
@@ -610,7 +649,7 @@ class TestConstructSetupPyFile:
 
 class TestBuildStandard:
     def test_default(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -619,7 +658,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -657,7 +696,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_default_no_reproducible(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -666,7 +705,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -705,7 +744,7 @@ class TestBuildStandard:
         assert stat.st_mtime != get_reproducible_timestamp()
 
     def test_default_support_legacy(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -714,7 +753,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -750,7 +789,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_artifacts(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -779,7 +818,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -821,7 +860,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_extra_dependencies(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -851,7 +890,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -893,7 +932,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_include_project_file(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -902,7 +941,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -942,7 +981,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_project_file_always_included(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -951,7 +990,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1000,7 +1039,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_config_file_always_included(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1009,7 +1048,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1060,7 +1099,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_include_readme(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1069,7 +1108,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1107,7 +1146,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_readme_always_included(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1116,7 +1155,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1161,7 +1200,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_include_license_files(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1170,7 +1209,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1208,7 +1247,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_license_files_always_included(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1217,7 +1256,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'readme': 'README.md'},
+            'project': {'name': project_name, 'dynamic': ['version'], 'readme': 'README.md'},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1262,7 +1301,7 @@ class TestBuildStandard:
         assert stat.st_mtime == get_reproducible_timestamp()
 
     def test_default_vcs_git_exclusion_files(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1278,7 +1317,7 @@ class TestBuildStandard:
         (project_path / 'my_app' / 'lib.h').touch()
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1317,7 +1356,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_vcs_mercurial_exclusion_files(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1347,7 +1386,7 @@ class TestBuildStandard:
         (project_path / 'my_app' / 'lib.h').touch()
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1384,3 +1423,50 @@ class TestBuildStandard:
             'sdist.standard_default_vcs_mercurial_exclusion_files', project_name, relative_root=builder.project_id
         )
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
+
+    def test_no_strict_naming(self, hatch, helpers, temp_dir):
+        project_name = 'My.App'
+
+        with temp_dir.as_cwd():
+            result = hatch('new', project_name)
+
+        assert result.exit_code == 0, result.output
+
+        project_path = temp_dir / 'my-app'
+        config = {
+            'project': {'name': project_name, 'dynamic': ['version']},
+            'tool': {
+                'hatch': {
+                    'version': {'path': 'my_app/__about__.py'},
+                    'build': {'targets': {'sdist': {'versions': ['standard'], 'strict-naming': False}}},
+                },
+            },
+        }
+        builder = SdistBuilder(str(project_path), config=config)
+
+        build_path = project_path / 'dist'
+
+        with project_path.as_cwd():
+            artifacts = list(builder.build())
+
+        assert len(artifacts) == 1
+        expected_artifact = artifacts[0]
+
+        build_artifacts = list(build_path.iterdir())
+        assert len(build_artifacts) == 1
+        assert expected_artifact == str(build_artifacts[0])
+        assert expected_artifact == str(build_path / f'{builder.artifact_project_id}.tar.gz')
+
+        extraction_directory = temp_dir / '_archive'
+        extraction_directory.mkdir()
+
+        with tarfile.open(str(expected_artifact), 'r:gz') as tar_archive:
+            tar_archive.extractall(str(extraction_directory))
+
+        expected_files = helpers.get_template_files(
+            'sdist.standard_default', project_name, relative_root=builder.project_id
+        )
+        helpers.assert_files(extraction_directory, expected_files, check_contents=True)
+
+        stat = os.stat(str(extraction_directory / builder.project_id / 'PKG-INFO'))
+        assert stat.st_mtime == get_reproducible_timestamp()
