@@ -325,6 +325,45 @@ class TestExtraMetadata:
         }
 
 
+class TestStrictNaming:
+    def test_default(self, isolation):
+        builder = WheelBuilder(str(isolation))
+
+        assert builder.config.strict_naming is builder.config.strict_naming is True
+
+    def test_target(self, isolation):
+        config = {'tool': {'hatch': {'build': {'targets': {'wheel': {'strict-naming': False}}}}}}
+        builder = WheelBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is False
+
+    def test_target_not_boolean(self, isolation):
+        config = {'tool': {'hatch': {'build': {'targets': {'wheel': {'strict-naming': 9000}}}}}}
+        builder = WheelBuilder(str(isolation), config=config)
+
+        with pytest.raises(TypeError, match='Field `tool.hatch.build.targets.wheel.strict-naming` must be a boolean'):
+            _ = builder.config.strict_naming
+
+    def test_global(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': False}}}}
+        builder = WheelBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is False
+
+    def test_global_not_boolean(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': 9000}}}}
+        builder = WheelBuilder(str(isolation), config=config)
+
+        with pytest.raises(TypeError, match='Field `tool.hatch.build.strict-naming` must be a boolean'):
+            _ = builder.config.strict_naming
+
+    def test_target_overrides_global(self, isolation):
+        config = {'tool': {'hatch': {'build': {'strict-naming': False, 'targets': {'wheel': {'strict-naming': True}}}}}}
+        builder = WheelBuilder(str(isolation), config=config)
+
+        assert builder.config.strict_naming is True
+
+
 class TestConstructEntryPointsFile:
     def test_default(self, isolation):
         config = {'project': {}}
@@ -415,7 +454,7 @@ class TestConstructEntryPointsFile:
 
 class TestBuildStandard:
     def test_default_auto_detection(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -425,7 +464,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -467,7 +506,7 @@ class TestBuildStandard:
             assert zip_info.date_time == (2020, 2, 2, 0, 0, 0)
 
     def test_default_reproducible_timestamp(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -476,7 +515,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -517,7 +556,7 @@ class TestBuildStandard:
             assert zip_info.date_time == (2020, 2, 2, 0, 1, 40)
 
     def test_default_no_reproducible(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -526,7 +565,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -567,7 +606,7 @@ class TestBuildStandard:
             assert zip_info.date_time == (2020, 2, 2, 0, 0, 0)
 
     def test_default_multiple_licenses(self, hatch, helpers, config_file, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
         config_file.model.template.licenses.default = ['MIT', 'Apache-2.0']
         config_file.save()
 
@@ -582,7 +621,7 @@ class TestBuildStandard:
         (project_path / 'LICENSES' / 'test').mkdir()
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'license-files': {'globs': ['LICENSES/*']}},
+            'project': {'name': project_name, 'dynamic': ['version'], 'license-files': {'globs': ['LICENSES/*']}},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -619,7 +658,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_include(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -629,7 +668,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -666,7 +705,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_only_packages(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -678,7 +717,7 @@ class TestBuildStandard:
         (tests_path / '__init__.py').replace(tests_path / 'foo.py')
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -719,7 +758,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_only_packages_artifact_override(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -731,7 +770,7 @@ class TestBuildStandard:
         (tests_path / '__init__.py').replace(tests_path / 'foo.py')
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -773,7 +812,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_python_constraint(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -782,7 +821,7 @@ class TestBuildStandard:
 
         project_path = temp_dir / 'my-app'
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -819,7 +858,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_default_tag(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -841,7 +880,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -883,7 +922,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_set_tag(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -906,7 +945,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -948,7 +987,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_known_artifacts(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -980,7 +1019,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1027,7 +1066,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_configured_build_hooks(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1059,7 +1098,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1106,7 +1145,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_extra_dependencies(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1139,7 +1178,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1186,7 +1225,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_dynamic_artifacts(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1219,7 +1258,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1265,7 +1304,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_build_script_dynamic_force_include(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1301,7 +1340,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1350,7 +1389,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1385,7 +1424,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -1431,7 +1470,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_shared_data(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1448,7 +1487,7 @@ class TestBuildStandard:
         (nested_data_path / 'bar.txt').touch()
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1488,7 +1527,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_extra_metadata(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1505,7 +1544,7 @@ class TestBuildStandard:
         (nested_data_path / 'bar.txt').touch()
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1544,7 +1583,7 @@ class TestBuildStandard:
 
     @pytest.mark.requires_unix
     def test_default_symlink(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1579,7 +1618,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'requires-python': '>3', 'dynamic': ['version']},
+            'project': {'name': project_name, 'requires-python': '>3', 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1630,7 +1669,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1640,7 +1679,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -1690,7 +1729,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1715,7 +1754,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -1765,7 +1804,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1791,7 +1830,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -1841,7 +1880,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1851,7 +1890,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -1905,7 +1944,7 @@ class TestBuildStandard:
 
     @fixed_pathlib_resolution
     def test_editable_exact(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1915,7 +1954,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -1962,7 +2001,7 @@ class TestBuildStandard:
 
     @fixed_pathlib_resolution
     def test_editable_exact_extra_dependencies(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -1987,7 +2026,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -2038,7 +2077,7 @@ class TestBuildStandard:
 
     @fixed_pathlib_resolution
     def test_editable_exact_force_include(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2064,7 +2103,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -2115,7 +2154,7 @@ class TestBuildStandard:
 
     @fixed_pathlib_resolution
     def test_editable_exact_force_include_option(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2125,7 +2164,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -2180,7 +2219,7 @@ class TestBuildStandard:
 
     @fixed_pathlib_resolution
     def test_editable_exact_force_include_build_data_precedence(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2206,7 +2245,7 @@ class TestBuildStandard:
         )
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -2265,7 +2304,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2275,7 +2314,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -2321,7 +2360,7 @@ class TestBuildStandard:
             assert zip_info.date_time == (2020, 2, 2, 0, 0, 0)
 
     def test_default_namespace_package(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2335,7 +2374,7 @@ class TestBuildStandard:
         package_path.replace(namespace_path / 'my_app')
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'namespace/my_app/__about__.py'},
@@ -2374,7 +2413,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_default_entry_points(self, hatch, helpers, temp_dir):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2384,7 +2423,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version'], 'scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}},
+            'project': {'name': project_name, 'dynamic': ['version'], 'scripts': {'foo': 'pkg:bar', 'bar': 'pkg:foo'}},
             'tool': {
                 'hatch': {
                     'version': {'path': 'my_app/__about__.py'},
@@ -2423,7 +2462,7 @@ class TestBuildStandard:
         config_file.model.template.plugins['default']['src-layout'] = True
         config_file.save()
 
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2433,7 +2472,7 @@ class TestBuildStandard:
         project_path = temp_dir / 'my-app'
 
         config = {
-            'project': {'name': 'my__app', 'dynamic': ['version']},
+            'project': {'name': project_name, 'dynamic': ['version']},
             'tool': {
                 'hatch': {
                     'version': {'path': 'src/my_app/__about__.py'},
@@ -2480,7 +2519,7 @@ class TestBuildStandard:
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
 
     def test_single_module(self, hatch, helpers, temp_dir, config_file):
-        project_name = 'My App'
+        project_name = 'My.App'
 
         with temp_dir.as_cwd():
             result = hatch('new', project_name)
@@ -2491,7 +2530,7 @@ class TestBuildStandard:
         (project_path / 'my_app').remove()
         (project_path / 'my_app.py').touch()
 
-        config = {'project': {'name': 'my__app', 'version': '0.0.1'}}
+        config = {'project': {'name': project_name, 'version': '0.0.1'}}
         builder = WheelBuilder(str(project_path), config=config)
 
         build_path = project_path / 'dist'
@@ -2520,3 +2559,51 @@ class TestBuildStandard:
             metadata_directory=metadata_directory,
         )
         helpers.assert_files(extraction_directory, expected_files, check_contents=True)
+
+    def test_no_strict_naming(self, hatch, helpers, temp_dir):
+        project_name = 'My.App'
+
+        with temp_dir.as_cwd():
+            result = hatch('new', project_name)
+
+        assert result.exit_code == 0, result.output
+
+        project_path = temp_dir / 'my-app'
+
+        config = {
+            'project': {'name': project_name, 'dynamic': ['version']},
+            'tool': {
+                'hatch': {
+                    'version': {'path': 'my_app/__about__.py'},
+                    'build': {'targets': {'wheel': {'versions': ['standard'], 'strict-naming': False}}},
+                },
+            },
+        }
+        builder = WheelBuilder(str(project_path), config=config)
+
+        build_path = project_path / 'dist'
+
+        with project_path.as_cwd():
+            artifacts = list(builder.build())
+
+        assert len(artifacts) == 1
+        expected_artifact = artifacts[0]
+
+        build_artifacts = list(build_path.iterdir())
+        assert len(build_artifacts) == 1
+        assert expected_artifact == str(build_artifacts[0])
+        assert expected_artifact == str(
+            build_path / f'{builder.artifact_project_id}-{get_python_versions_tag()}-none-any.whl'
+        )
+
+        extraction_directory = temp_dir / '_archive'
+        extraction_directory.mkdir()
+
+        with zipfile.ZipFile(str(expected_artifact), 'r') as zip_archive:
+            zip_archive.extractall(str(extraction_directory))
+
+        metadata_directory = f'{builder.artifact_project_id}.dist-info'
+        expected_files = helpers.get_template_files(
+            'wheel.standard_no_strict_naming', project_name, metadata_directory=metadata_directory
+        )
+        helpers.assert_files(extraction_directory, expected_files, check_contents=True)
