@@ -13,7 +13,7 @@ def local_builder(mock_backend_process, mocker):
 
 
 def test(hatch, temp_dir, helpers):
-    project_name = 'My App'
+    project_name = 'My.App'
 
     with temp_dir.as_cwd():
         result = hatch('new', project_name)
@@ -42,7 +42,7 @@ def test(hatch, temp_dir, helpers):
 
     project = Project(path)
     config = dict(project.raw_config)
-    config['tool']['hatch']['build']['hooks'] = {'custom': {'path': build_script.name}}
+    config['tool']['hatch']['build'] = {'hooks': {'custom': {'path': build_script.name}}}
     project.save_config(config)
 
     with path.as_cwd():
