@@ -13,7 +13,7 @@ def get_files(**kwargs):
     files = []
     for f in get_template_files(**kwargs):
         if str(f.path) == 'LICENSE.txt':
-            files.append(File(Path(metadata_directory, 'license_files', f.path), f.contents))
+            files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
 
         if f.path.parts[0] != kwargs['package_name']:
             continue
@@ -37,7 +37,7 @@ Tag: {kwargs.get('tag', '')}
             Path(metadata_directory, 'METADATA'),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name_normalized']}
+Name: {kwargs['project_name']}
 Version: 0.0.1
 Requires-Python: >3
 Requires-Dist: binary
