@@ -14,7 +14,7 @@ def get_files(**kwargs):
     files = []
     for f in get_template_files(**kwargs):
         if str(f.path) == 'LICENSE.txt':
-            files.append(File(Path(metadata_directory, 'license_files', f.path), f.contents))
+            files.append(File(Path(metadata_directory, 'licenses', f.path), f.contents))
         elif f.path.parts[-1] == '__about__.py':
             files.append(File(Path('zfoo.py'), f.contents))
 
@@ -37,7 +37,7 @@ Tag: py3-none-any
             Path(metadata_directory, 'METADATA'),
             f"""\
 Metadata-Version: {DEFAULT_METADATA_VERSION}
-Name: {kwargs['project_name_normalized']}
+Name: {kwargs['project_name']}
 Version: 0.0.1
 """,
         )
